<?php

namespace App\Entity;

use App\Repository\QuestionRepository;
use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\ORM\Mapping as ORM;

#[ORM\Entity(repositoryClass: QuestionRepository::class)]
class Question
{
    #[ORM\Id]
    #[ORM\GeneratedValue]
    #[ORM\Column]
    private ?int $id = null;

    #[ORM\Column(length: 255)]
    private ?string $libelle = null;

    #[ORM\Column(length: 50)]
    private ?string $typeQuestion = null;

    #[ORM\ManyToOne(inversedBy: 'questions')]
    private ?dimension $dimension = null;

    /**
     * @var Collection<int, ReponsePossible>
     */
    #[ORM\OneToMany(targetEntity: ReponsePossible::class, mappedBy: 'question')]
    private Collection $reponsePossibles;

    /**
     * @var Collection<int, ReponseUtilisateur>
     */
    #[ORM\OneToMany(targetEntity: ReponseUtilisateur::class, mappedBy: 'question')]
    private Collection $reponseUtilisateurs;

    public function __construct()
    {
        $this->reponsePossibles = new ArrayCollection();
        $this->reponseUtilisateurs = new ArrayCollection();
    }

    public function getId(): ?int
    {
        return $this->id;
    }

    public function getLibelle(): ?string
    {
        return $this->libelle;
    }

    public function setLibelle(string $libelle): static
    {
        $this->libelle = $libelle;

        return $this;
    }

    public function getTypeQuestion(): ?string
    {
        return $this->typeQuestion;
    }

    public function setTypeQuestion(string $typeQuestion): static
    {
        $this->typeQuestion = $typeQuestion;

        return $this;
    }

    public function getDimension(): ?dimension
    {
        return $this->dimension;
    }

    public function setDimension(?dimension $dimension): static
    {
        $this->dimension = $dimension;

        return $this;
    }

    /**
     * @return Collection<int, ReponsePossible>
     */
    public function getReponsePossibles(): Collection
    {
        return $this->reponsePossibles;
    }

    public function addReponsePossible(ReponsePossible $reponsePossible): static
    {
        if (!$this->reponsePossibles->contains($reponsePossible)) {
            $this->reponsePossibles->add($reponsePossible);
            $reponsePossible->setQuestion($this);
        }

        return $this;
    }

    public function removeReponsePossible(ReponsePossible $reponsePossible): static
    {
        if ($this->reponsePossibles->removeElement($reponsePossible)) {
            // set the owning side to null (unless already changed)
            if ($reponsePossible->getQuestion() === $this) {
                $reponsePossible->setQuestion(null);
            }
        }

        return $this;
    }

    /**
     * @return Collection<int, ReponseUtilisateur>
     */
    public function getReponseUtilisateurs(): Collection
    {
        return $this->reponseUtilisateurs;
    }

    public function addReponseUtilisateur(ReponseUtilisateur $reponseUtilisateur): static
    {
        if (!$this->reponseUtilisateurs->contains($reponseUtilisateur)) {
            $this->reponseUtilisateurs->add($reponseUtilisateur);
            $reponseUtilisateur->setQuestion($this);
        }

        return $this;
    }

    public function removeReponseUtilisateur(ReponseUtilisateur $reponseUtilisateur): static
    {
        if ($this->reponseUtilisateurs->removeElement($reponseUtilisateur)) {
            // set the owning side to null (unless already changed)
            if ($reponseUtilisateur->getQuestion() === $this) {
                $reponseUtilisateur->setQuestion(null);
            }
        }

        return $this;
    }
}
